package com.snake;

import com.snake.templates.AbstractSnake;
import java.util.ArrayList;
import java.util.List;

/**
 * Class representing the Snake in the game, tracking each of its
 * body parts
 */
public class Snake extends AbstractSnake {

   private final Board board;
   // The direction of the head- this can be changed by keyboard input
   private Direction dir = Direction.SOUTH;

   // Keep track of the Snake parts
   private Cell head;
   private List<Cell> body = new ArrayList<Cell>();
   private Cell tail;

   public Snake(Board board) {
      this.board = board;
   }

   /**
    * Place the Snake on the board
    */
   public void place() {
      Cell head = board.getCell(0, 2);
      head.setType(CellType.HEAD);
      this.head = head;

      Cell body = board.getCell(0, 1);
      body.setType(CellType.BODY);
      // Notice we use .add() method to add to the list
      this.body.add(body);

      Cell tail = board.getCell(0, 0);
      tail.setType(CellType.TAIL);
      this.tail = tail;
   }

   /**
    * Set the direction for the next game move
    */
   public void setDirection(Direction dir) {
      this.dir = dir;
   }

   /**
    * Actually move the Snake, based on the current direction of
    * existing Snake cells, and the dir field.
    */
   public void move() {
      int row = head.getRow();
      int col = head.getCol();

      // Reset the current head Cell to be empty
      head.setType(CellType.EMPTY);
      head.setDirection(Direction.NONE);

      switch (dir) {
         case NORTH:
            row--;
            break;
         case EAST:
            col++;
            break;
         case WEST:
            col--;
            break;
         case SOUTH:
            row++;
            break;
      }


      head = board.getCell(row, col);
      head.setType(CellType.HEAD);
      head.setDirection(dir);

      board.getBoardUI().repaint();
   }
}
