package snakegametest.socket;

import java.awt.BorderLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import javax.swing.*;
import javax.swing.border.EmptyBorder;
import javax.swing.event.ListSelectionEvent;
import javax.swing.event.ListSelectionListener;

/**
 *
 */
public class SnakeServerUI extends JFrame {

   private JPanel panel;
   private JTextArea reportDisplayArea;
   private final String SPACING = "     ";
   private JList listBox;
   private int portNumber;
   private SnakeServer serverThread;
   private JButton startServerBtn;
   private boolean serverStarted = false;

   public SnakeServerUI () {
      setupUI();
      addPanel();

      getPortNumber();
      serverThread = new SnakeServer(portNumber);
   }

   private void setupUI() {
      // Here we set the title and size of the window
      setTitle("Snake Report Collector");
      setSize(450, 300);
      setResizable(true);

      // This tells the program to exit when the red 'X' in the top right
      // corner is clicked
      setDefaultCloseOperation(EXIT_ON_CLOSE);

      // This makes the window appear in the middle, and stops you from
      // resizing the window
      setLocationRelativeTo(null);
      setResizable(true);

      setFocusable(true);
   }

      /**
    * Add the list of failed tests and the hint area
    */
   private void addPanel() {
      panel = new JPanel(new BorderLayout(20, 10));
      panel.setBorder(new EmptyBorder(10, 10, 10, 10));
      getContentPane().add(panel, BorderLayout.CENTER);

      setupReportsList();

      JPanel reportPanel = new JPanel(new BorderLayout(0, 20));
      panel.add(reportPanel, BorderLayout.EAST);

      reportDisplayArea = new JTextArea(30, 70);
      // Set the text to the initial failure message
      reportDisplayArea.setText("Select a report to display here.");
      reportDisplayArea.setEditable(false);
      reportPanel.add(new JScrollPane(reportDisplayArea), BorderLayout.CENTER);

      JPanel buttonPanel = new JPanel();
      panel.add(buttonPanel, BorderLayout.SOUTH);

      JButton refreshReports = new JButton("Refresh reports");
      refreshReports.addActionListener(new ActionListener() {

         @Override
         public void actionPerformed(ActionEvent e) {
            listBox.setListData(getUserNames());
         }
      });

      startServerBtn = new JButton("Start Server");
      startServerBtn.addActionListener(new ActionListener() {

         @Override
         public void actionPerformed(ActionEvent e) {
            if (!serverStarted) {
               serverThread.start();
               serverStarted = true;
               startServerBtn.setText("Server started");
               startServerBtn.setEnabled(false);
            }
         }
      });

      buttonPanel.add(refreshReports, BorderLayout.WEST);
      buttonPanel.add(startServerBtn, BorderLayout.EAST);
      
      pack();
   }

   /**
    * Set up the listbox showing test failures, and add a selection listener
    * so that we can initially display the error message
    */
   private void setupReportsList() {

      listBox = new JList(getUserNames());
      listBox.setSelectedIndex(0);
      listBox.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
      panel.add(new JScrollPane(listBox), BorderLayout.WEST);

      listBox.addListSelectionListener(new ListSelectionListener() {

         @Override
         public void valueChanged(ListSelectionEvent e) {
            JList source = (JList) e.getSource();
            String user = (String) source.getSelectedValue();

            if (user != null)
               reportDisplayArea.setText(getReportForUser(user.replace(SPACING, "")));
         }
      });
   }

   private String getReportForUser(String userName) {
      List<String> reportLines = getLinesFromFile("reports/report."+userName + ".txt");
      String report = "";

      for (String line : reportLines) {
         report += line + "\n";
      }

      return report;
   }

   public String[] getUserNames() {

      File reportsFolder = new File("reports/");
      File[] files = reportsFolder.listFiles();

      String[] userNames = new String[files.length];

      if (reportsFolder.isDirectory()) {
         for (int i = 0; i < userNames.length; i++) {
            // Report file name in format report.<username>.txt
            String[] reportParts = files[i].getName().split("\\.");
            userNames[i] = reportParts[1] + SPACING;
         }
      }

      return userNames;
   }

   public static void main (String[] args) {
      SwingUtilities.invokeLater(new Runnable() {

         @Override
         public void run() {
            SnakeServerUI ui = new SnakeServerUI();
            ui.setVisible(true);
         }
      });
   }

   private void getPortNumber() {
      List<String> portDetails = getLinesFromFile("conn.txt");
      if (portDetails.isEmpty())
         portNumber = 7;
      else
         portNumber = Integer.parseInt(portDetails.get(1));
   }

   /**
    * Return the lines of the given file as Strings
    */
   public static List<String> getLinesFromFile(String fileName) {
      File file = new File(fileName);
      List<String> lines = new ArrayList<String>();
      if (!file.exists()) {
         return lines;
      }

      BufferedReader reader = null;
      try {
         reader = new BufferedReader(new FileReader(file));

         String line;
         while ((line = reader.readLine()) != null) {
            lines.add(line);
         }
      } catch (Exception e) {
         e.printStackTrace();
      } finally {
         try {
            if (reader != null) reader.close();
         } catch (IOException e) {}
      }
      return lines;
   }
}
